import React from 'react';
import classNames from 'classnames';
import { SyncOutlined, CheckCircleTwoTone, CloseCircleTwoTone } from '@ant-design/icons';
import { Input } from 'antd';
import { checkCaptch } from '@/services/login';
import CaptchaImage from './CaptchaImage';

export default (props) => {
  const { style, className, onChange, onBlur, ...leftProps } = props;

  const [captcha, setCaptcha] = React.useState();
  const [value, setValue] = React.useState();
  const [isOk, setIsOk] = React.useState(-1);

  const handleChange = (e) => {
    setValue(e.target.value);
  };

  const handleBlur = (e) => {
    if (onBlur) {
      onBlur(e);
    }

    checkCaptch({ id: captcha?.id, value }).then((res) => {
      setIsOk(res);
    });
  };

  const onCaptchaChange = (e) => {
    setIsOk(-1);
    setValue();
    setCaptcha(e);
  };

  React.useEffect(() => {
    if (onChange) {
      onChange({
        id: captcha?.id,
        value,
      });
    }
  }, [value, captcha]);

  return (
    <div className={classNames(className, 'flex', 'v-center')} style={style}>
      <div className="flex-1">
        <Input
          allowClear
          {...leftProps}
          value={value}
          onChange={handleChange}
          onBlur={handleBlur}
        />
      </div>
      <div className="flex-0" style={{ width: '130px', marginLeft: '8px' }}>
        <CaptchaImage onChange={onCaptchaChange} />
      </div>
      <div className="flex-0" style={{ width: '24px', marginLeft: '8px' }}>
        {isOk === -1 && <SyncOutlined style={{ fontSize: '16px', color: '#096dd9' }} />}
        {isOk === 1 && <CheckCircleTwoTone twoToneColor="#00ff00" style={{ fontSize: '18px' }} />}
        {isOk === 0 && <CloseCircleTwoTone twoToneColor="#ff0000" style={{ fontSize: '18px' }} />}
      </div>
    </div>
  );
};
